%define major 7
%define inchi_major 0
%define coordgen_major 1
%define maeparser_major 1
%define libname %mklibname %{name} %{major}
%define inchilib %mklibname inchi %{inchi_major}
%define libcoordgen %mklibname coordgen %{coordgen_major}
%define libmaeparser %mklibname maeparser %{maeparser_major}
%define devname %mklibname %{name} -d

Summary:	Chemistry software file format converter
Name:		openbabel
Version:	3.1.1
Release:	7
License:	GPLv2+
Group:		Sciences/Chemistry
Url:		http://openbabel.org
Source0:	https://github.com/openbabel/openbabel/releases/download/%{name}-%(echo %{version} | tr '.' '-')/%{name}-%{version}-source.tar.bz2
Source1:	openbabelgui.desktop
# Missing file: data/ring-fragments-index.txt #2613
# https://github.com/openbabel/openbabel/issues/2613
Source2:        ring-fragments-index.txt

# Fix some warnings CMakeLists.txt
Patch1:		%{name}-cmakelists.patch
# Fix plugin directory location (#680292, patch by lg)
Patch2:		%{name}-plugindir.patch
# Fix UB in UFF parameter parsing. Bug 2224
Patch3:		%{name}-bug2224.patch
# Fix perl modules install path and 1 warning
Patch4:		%{name}-perl.patch
# Fix test failure with Python 3
Patch5:		%{name}-python-bug2217.patch
# Fix path to libdir in .pc file
# https://bugzilla.redhat.com/show_bug.cgi?id=1669664
Patch6:		%{name}-fix-libdir-in-pkgconfig.patch
Patch7:		openbabel-plugindir2.patch
Patch9:		openbabel-2.4.1-gcc12.patch
Patch11:	%{name}-3.1.1-bug2378.patch
Patch12:	%{name}-3.1.1-bug2493.patch
BuildRequires:	boost-devel
BuildRequires:	maeparser-devel
BuildRequires:	coordgen-devel
BuildRequires:	cmake
BuildRequires:	eigen3
BuildRequires:	libtool
BuildRequires:	doxygen
BuildRequires:	swig
BuildRequires:	perl-devel
BuildRequires:	ruby-devel
BuildRequires:	wxgtku3.2-devel
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(RapidJSON)
BuildRequires:	perl(ExtUtils::MakeMaker)

%description
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

%files
%config(noreplace) %{_sysconfdir}/profile.d/openbabel3.csh
%config(noreplace) %{_sysconfdir}/profile.d/openbabel3.sh
%doc AUTHORS COPYING THANKS
%doc doc/*.html doc/diox* doc/README*
%{_bindir}/*
%{_mandir}/man?/*
%{_datadir}/%{name}
%{_libdir}/%{name}

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared libraries of %{name}
Group:		System/Libraries

%description -n %{libname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package contains shared libraries of %{name}.

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{inchilib}
Summary:	Shared libraries of inchi
Group:		System/Libraries

%description -n %{inchilib}
The IUPAC International Chemical Identifier (InChITM) is a non-proprietary
identifier for chemical substances that can be used in printed and
electronic data sources thus enabling easier linking of diverse data
compilations. It was developed under IUPAC Project 2000-025-1-800 during
the period 2000-2004. Details of the project and the history of its
progress are available from the project web site.

This package contains shared libraries of inchi.

%files -n %{inchilib}
%{_libdir}/libinchi.so.%{inchi_major}*

#----------------------------------------------------------------------------
%package -n %{devname}
Summary:	Development files of %{name}
Group:		Development/C++
Requires:	%{libname} = %{EVRD}
Requires:	%{inchilib} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}

%description -n %{devname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package includes the header files and other development
related files necessary for developing or compiling programs
using the %{name} library.

%files -n %{devname}
%{_includedir}/*
%{_libdir}/cmake/openbabel3
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib*.so
#----------------------------------------------------------------------------

%package -n perl-%{name}
Summary:	Perl wrapper for the Open Babel library
Group:		Development/Perl

%description -n perl-%{name}
Perl wrapper for the Open Babel library.

%files -n perl-%{name}
%{perl_vendorarch}/*

#----------------------------------------------------------------------------

%package -n python3-%{name}
Summary:	Python wrapper for the Open Babel library
Group:		Development/Python
%rename python-%{name}

%description -n python3-%{name}
Python wrapper for the Open Babel library.

%files -n python3-%{name}
%{python3_sitearch}/*

#----------------------------------------------------------------------------

%if 0
%package -n ruby-%{name}
Summary:	Ruby wrapper for the Open Babel library
Group:		Development/Ruby
Requires:	%{name} = %{EVRD}

%description -n ruby-%{name}
Ruby wrapper for the Open Babel library.

%files -n ruby-%{name}
%{ruby_sitearchdir}/openbabel.so
%endif

#----------------------------------------------------------------------------

%prep
%autosetup -p1

# we use system libs
rm -rf ./external/*

%build
%ifarch x86_64 i686
LDFLAGS='%{ldflags} -ltirpc'
%endif
%cmake \
	-DENABLE_TESTS:BOOL=OFF \
	-DBUILD_GUI:BOOL=ON \
	-DENABLE_VERSIONED_FORMATS=false \
	-DPYTHON_BINDINGS:BOOL=ON \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DPERL_BINDINGS:BOOL=ON \
	-DRUBY_BINDINGS:BOOL=OFF \
	-DRUN_SWIG=ON \
        -DBUILD_DOCS=ON \
	-DOPENBABEL_USE_SYSTEM_INCHI=OFF
%make -s

%install
%makeinstall_std -C build
install -p -D -m 644 %{SOURCE2} %{buildroot}/usr/share/openbabel/3.1.1/

# Create profile files
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
cat > %{buildroot}%{_sysconfdir}/profile.d/openbabel3.sh <<EOF
BABEL_LIBDIR=%{_libdir}/%{name}
export BABEL_LIBDIR
BABEL_DATADIR=%{_datadir}/%{name}/%{version}
export BABEL_DATADIR
EOF
cat > %{buildroot}%{_sysconfdir}/profile.d/openbabel3.csh <<EOF
setenv BABEL_LIBDIR %{_libdir}/%{name}
setenv BABEL_DATADIR %{_datadir}/%{name}/%{version}
EOF

%changelog
* Mon Sep 30 2024 Aleksandr Proklov <a.proklov@rosalinux.ru> c3f55a5  (HEAD, origin/rosa2023.1)
- more patch from fedora

* Mon Sep 30 2024 Aleksandr Proklov <a.proklov@rosalinux.ru> 9bb87cd  (tag: rosa2023.1-3.1.1-5)
- add requires

* Mon Sep 30 2024 Aleksandr Proklov <a.proklov@rosalinux.ru> b3530ae  (tag: rosa2023.1-3.1.1-4)
- fix cmake files

* Fri Sep 13 2024 Aleksandr Proklov <a.proklov@rosalinux.ru> 6f9f661  (tag: rosa2023.1-3.1.1-3)
- restore BR

* Fri Sep 13 2024 Aleksandr Proklov <a.proklov@rosalinux.ru> 5668303
- add more fix from https://forum.rosalinux.ru/viewtopic.php?f=48&p=117856&sid=4d06adb32c3d08a5397e2cc070d86f3e#p117856

* Mon Sep  9 2024 Aleksandr Proklov <a.proklov@rosalinux.ru> 18c11e6  (tag: rosa2023.1-3.1.1-2)
- rename python pkg